@@ -8,13 +8,13 @@ use MooX::LazierAttributes;
 use Eliza::Chatbot::Option;
 use Eliza::Chatbot::Brain;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our @user_options = qw(name script_file debug prompts_on memory_on);
 
 attributes (
-    (map { $_ => [qw/rw/] } @user_options),
-    brain => ['rw', undef, { lazy => 1, builder => 1 }],
+    (map { $_ => [rw] } @user_options),
+    brain => [rw, nan, { lzy, bld }],
 );
 
 sub _build_brain {
@@ -104,7 +104,7 @@ Eliza::Chatbot - Eliza chatbot
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =head1 SYNOPSIS
 
